package cn.fw.dalaran.common.exception;

import java.io.PrintWriter;
import java.io.StringWriter;

public class ResponseMessage<T> {
    public static final int SUCCESS_CODE = 0;
    public static final int FAILURE_CODE = -1;
    private boolean isSuccess = true;
    private int code;
    private String result;
    private T data;

    public ResponseMessage() {
    }

    public ResponseMessage(int code, String result) {
        this.code = code;
        this.result = result;
    }

    public ResponseMessage(boolean isSuccess, int code, String result) {
        this.isSuccess = isSuccess;
        this.code = code;
        this.result = result;
    }

    public int getCode() {
        return this.code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getResult() {
        return this.result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public T getData() {
        return this.data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public boolean isSuccess() {
        return this.isSuccess;
    }

    public void setSuccess(boolean success) {
        this.isSuccess = success;
    }

    private static <T> ResponseMessage<T> create(boolean isSuccess, int code, String result) {
        return new ResponseMessage<T>(isSuccess, code, result);
    }

    public static <T> ResponseMessage<T> success() {
        return success(SUCCESS_CODE, "操作成功!");
    }

    public static <T> ResponseMessage<T> success(T data) {
        ResponseMessage<T> message = success(SUCCESS_CODE, "操作成功!");
        message.setData(data);
        return message;
    }

    public static <T> ResponseMessage<T> success(int code, String msg) {
        return create(true, code, msg);
    }

    public static <T> ResponseMessage<T> failure() {
        return failure("操作失败!");
    }

    public static <T> ResponseMessage<T> failure(String msg) {
        return failure(FAILURE_CODE, msg);
    }

    public static <T> ResponseMessage<T> failure(int code, String msg) {
        return create(false, code, msg);
    }

    public static <T> ResponseMessage<T> failure(Exception ex) {
        return failure("系统异常:" + ex.getMessage(), ex);
    }

    public static <T> ResponseMessage<T> failure(String message, Exception ex) {
        if (ex == null) {
            return failure();
        } else {
            ResponseMessage<T> msg = failure(message);

            try {
                StringWriter sw = new StringWriter();
                ex.printStackTrace(new PrintWriter(sw));
                msg.setData((T) sw.toString());
            } catch (Exception e) {
                e.printStackTrace();
            }

            return msg;
        }
    }
}
