package cn.fw.dalaran.domain.dto;

import cn.fw.common.validator.EnumValue;
import cn.fw.dalaran.domain.enums.PlatformEnum;
import lombok.Data;
import lombok.ToString;

import javax.validation.constraints.NotBlank;
import java.util.Date;
import java.util.List;

/**
 * @author kurisu
 * @date 2021-11-16 15:44
 * @description 短视频DTO
 */
@Data
@ToString(callSuper = true)
public class VideoPoolDTO {
    /**
     * 账号
     */
    @NotBlank(message = "账号不能为空")
    private String account;
    /**
     * 平台类型
     */
    @EnumValue(enumClass = PlatformEnum.class, message = "无效的账号类型")
    private Integer type;

    private List<VideoDTO> videoList;

    @Data
    public static class VideoDTO {
        /**
         * 视频id
         */
        private String videoId;
        /**
         * 播放地址
         */
        private String playUrl;
        /**
         * 视频标题
         */
        private String title;
        /**
         * 预览图
         */
        private String preview;
        /**
         * 观看人数
         */
        private Integer uv;
        /**
         * 完整观看人数
         */
        private Integer fullUv;
        /**
         * 点赞数
         */
        private Integer likeNum;
        /**
         * 分享数
         */
        private Integer shareNum;
        /**
         * 评论数
         */
        private Integer commentNum;
        /**
         * 新增粉丝数
         */
        private Integer newFanNum;
        /**
         * 时长（秒）
         */
        private Integer duration;
        /**
         * 话题
         */
        private String tags;
        /**
         * 发布时间
         */
        private Date publishTime;
    }
}
