package cn.fw.dalaran.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * @author kurisu
 * @date 2020-08-11 17:37
 * @description 子指标类型
 */
public enum SubTypeEnum implements IEnum<Integer> {
    /**
     * 观看人数/播放量
     */
    UV(1, "观看人数", null),

    /**
     * 完整播放量
     */
    FULL_UV(6, "完整播放量", BizTypeEnum.VIDEO),

    /**
     * 在线峰值
     */
    UV_PEAK(7, "在线峰值", BizTypeEnum.LIVE),
    /**
     * 直播时长
     */
    LIVE_DURATION(8, "直播时长", BizTypeEnum.LIVE),

    /**
     * 点赞
     */
    LIKE(2, "点赞", null),
    /**
     * 分享
     */
    SHARE(3, "分享", null),
    /**
     * 评论
     */
    COMMENT(4, "评论", null),
    /**
     * 增粉
     */
    NEW_FANS(5, "增粉", null),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;
    /**
     * 所属业务类型
     */
    private final BizTypeEnum bizType;

    SubTypeEnum(final Integer value, final String name, final BizTypeEnum bizType) {
        this.value = value;
        this.name = name;
        this.bizType = bizType;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SubTypeEnum ofValue(final Integer value) {
        for (final SubTypeEnum typeEnum : SubTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SubTypeEnum typeEnum : SubTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    public static List<SubTypeEnum> getByBizType(final BizTypeEnum bizType) {
        List<SubTypeEnum> list = new ArrayList<>();
        for (final SubTypeEnum typeEnum : SubTypeEnum.values()) {
            if (Objects.isNull(typeEnum.bizType) || bizType.equals(typeEnum.bizType)) {
                list.add(typeEnum);
            }
        }
        return list;
    }
}
