package cn.fw.dalaran.server.controller.app;

import cn.fw.common.page.AppPage;
import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.dalaran.domain.db.LivePool;
import cn.fw.dalaran.domain.db.VideoPool;
import cn.fw.dalaran.domain.dto.DelPoolParam;
import cn.fw.dalaran.domain.dto.PoolQueryDTO;
import cn.fw.dalaran.domain.vo.LivePoolVO;
import cn.fw.dalaran.domain.vo.VideoPoolVO;
import cn.fw.dalaran.service.biz.PoolBizService;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 *@author kurisu
 * @date 2021-11-17 15:02
 * @description 短视频/直播池控制器
 */
@Slf4j
@Validated
@RestController
@RequiredArgsConstructor
@Authorization(AuthType.APP)
@RequestMapping("/pool")
public class PoolController {
    private final PoolBizService poolBizService;

    @GetMapping("/video/list")
    @ControllerMethod("短视频池查询")
    @IgnoreAuth
    public Message<AppPage<VideoPoolVO>> videoList(PoolQueryDTO queryDTO) {
        return success(poolBizService.videoList(queryDTO));
    }

    @GetMapping("/live/list")
    @ControllerMethod("直播池查询")
    @IgnoreAuth
    public Message<AppPage<LivePoolVO>> liveList(PoolQueryDTO queryDTO) {
        return success(poolBizService.liveList(queryDTO));
    }

    @PostMapping("/video/del")
    @ControllerMethod("删除视频")
    @IgnoreAuth
    public Message<Boolean> delVideo(@RequestBody DelPoolParam param) {
        return success(poolBizService.delVideo(param));
    }

    @PostMapping("/live/del")
    @ControllerMethod("删除直播")
    @IgnoreAuth
    public Message<Boolean> delLive(@RequestBody DelPoolParam param) {
        return success(poolBizService.delLive(param));
    }

    @PostMapping("/video/update")
    @ControllerMethod("更新视频")
    @IgnoreAuth
    public Message<Boolean> updateVideo(@RequestBody VideoPool param) {
        return success(poolBizService.updateVideo(param));
    }

    @PostMapping("/live/update")
    @ControllerMethod("更新直播")
    @IgnoreAuth
    public Message<Boolean> updateLive(@RequestBody LivePool param) {
        return success(poolBizService.updateLive(param));
    }
}
